@@ -36,7 +36,6 @@ struct _GeditMultiNotebookPrivate
 	GeditTab  *active_tab;
 
 	guint      removing_notebook : 1;
-	guint      collapse : 1;
 };
 
 enum
@@ -450,6 +449,12 @@ add_notebook (GeditMultiNotebook *mnb,
 
 		mnb->priv->notebooks = g_list_append (mnb->priv->notebooks,
 		                                      notebook);
+
+		gtk_style_context_add_class (gtk_widget_get_style_context (notebook),
+		                             "first");
+
+		gtk_style_context_add_class (gtk_widget_get_style_context (notebook),
+		                             "last");
 	}
 	else
 	{
@@ -458,7 +463,6 @@ add_notebook (GeditMultiNotebook *mnb,
 		GtkAllocation allocation;
 		GtkWidget *active_notebook = mnb->priv->active_notebook;
 		gint active_nb_pos;
-		gboolean collapse_new_notebook = FALSE;
 
 		paned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 		gtk_widget_show (paned);
@@ -472,6 +476,16 @@ add_notebook (GeditMultiNotebook *mnb,
 		gtk_container_remove (GTK_CONTAINER (parent), active_notebook);
 		gtk_container_add (GTK_CONTAINER (parent), paned);
 
+		/* check if we need to uncollapse the active notebook */
+		if (active_notebook == g_list_last (mnb->priv->notebooks)->data)
+		{
+			gtk_style_context_remove_class (gtk_widget_get_style_context (active_notebook),
+			                                "last");
+
+			gtk_style_context_add_class (gtk_widget_get_style_context (notebook),
+			                             "last");
+		}
+
 		gtk_paned_pack1 (GTK_PANED (paned), active_notebook, TRUE, FALSE);
 		g_object_unref (active_notebook);
 
@@ -481,26 +495,11 @@ add_notebook (GeditMultiNotebook *mnb,
 		gtk_paned_set_position (GTK_PANED (paned),
 		                        allocation.width / 2);
 
-		/* check if we need to uncollapse the active notebook */
-		if (active_notebook == g_list_last (mnb->priv->notebooks)->data &&
-		    mnb->priv->collapse)
-		{
-			collapse_new_notebook = TRUE;
-			gedit_notebook_collapse_border (GEDIT_NOTEBOOK (active_notebook),
-			                                FALSE);
-		}
-
 		active_nb_pos = g_list_index (mnb->priv->notebooks,
 		                              active_notebook);
 		mnb->priv->notebooks = g_list_insert (mnb->priv->notebooks,
 		                                      notebook,
 		                                      active_nb_pos + 1);
-
-		if (collapse_new_notebook)
-		{
-			gedit_notebook_collapse_border (GEDIT_NOTEBOOK (notebook),
-			                                TRUE);
-		}
 	}
 
 	gtk_widget_show (notebook);
@@ -532,14 +531,25 @@ remove_notebook (GeditMultiNotebook *mnb,
 	if (current->next != NULL)
 	{
 		new_notebook = GTK_WIDGET (current->next->data);
+
+		if (current->prev == NULL)
+		{
+			gtk_style_context_add_class (gtk_widget_get_style_context (new_notebook),
+			                             "first");
+		}
 	}
 	else
 	{
 		new_notebook = GTK_WIDGET (mnb->priv->notebooks->data);
 
-		/* we must check if we need to collapse the new last notebook */
-		gedit_notebook_collapse_border (GEDIT_NOTEBOOK (current->prev->data),
-		                                mnb->priv->collapse);
+		gtk_style_context_add_class (gtk_widget_get_style_context (current->prev->data),
+		                             "last");
+	}
+
+	if (current->prev == NULL)
+	{
+		gtk_style_context_remove_class (gtk_widget_get_style_context (notebook),
+		                                "first");
 	}
 
 	parent = gtk_widget_get_parent (notebook);
@@ -574,6 +584,9 @@ remove_notebook (GeditMultiNotebook *mnb,
 	g_object_unref (children->data);
 	g_list_free (children);
 
+	gtk_style_context_remove_region (gtk_widget_get_style_context (notebook),
+	                                 "notebook");
+
 	disconnect_notebook_signals (mnb, notebook);
 
 	g_signal_emit (G_OBJECT (mnb), signals[NOTEBOOK_REMOVED], 0, notebook);
@@ -905,21 +918,6 @@ gedit_multi_notebook_next_notebook (GeditMultiNotebook *mnb)
 	gtk_widget_grab_focus (notebook);
 }
 
-void
-gedit_multi_notebook_collapse_notebook_border (GeditMultiNotebook *mnb,
-					       gboolean            collapse)
-{
-	GeditNotebook *notebook;
-
-	g_return_if_fail (GEDIT_IS_MULTI_NOTEBOOK (mnb));
-
-	mnb->priv->collapse = (collapse != FALSE);
-
-	notebook = GEDIT_NOTEBOOK (g_list_last (mnb->priv->notebooks)->data);
-
-	gedit_notebook_collapse_border (notebook, collapse);
-}
-
 void
 gedit_multi_notebook_foreach_notebook (GeditMultiNotebook *mnb,
 				       GtkCallback         callback,
